import { ActionItem, BasicColumn, FormSchema } from '/@/components/Table';
import { useMessage } from '/@/hooks/web/useMessage';
import { useI18n } from '/@/hooks/web/useI18n';
import { getEntity } from '/@/api/tigerapi/system';
import { Ref } from 'vue';
import { buildUUID } from '/@/utils/uuid';
import { useUserStore } from '/@/store/modules/user';
import { formatToDateTime } from '/@/utils/dateUtil';
import { isNullOrEmpty } from '/@/utils/is';

const { t } = useI18n();
const { notification } = useMessage();

/**
 * @description: 自定义编辑方法，跳转到高级页面
 * @param {Fn} args
 * @param {*} params
 * @return {*}
 */
export function pkgGrpEdit(args: Fn[], params: {}) {
    const param = { CODE: params['record']['RULE_CODE'], ID: params['record']['ID'], Name: 'BAS_PKG_DTL', Title: `编辑包装规则：${params['record']['RULE_CODE']}`, pCode: 'PKG_RULE_ID', IsID: true };
    args[5](`/BAS_PKG_DTL/High/${encodeURI(JSON.stringify(param))}`);
  }


/**
 * @description: 自定义明细表中编辑返回方法
 * @param {string} type
 * @param {*} d
 * @param {*} u
 * @return {*}
 */
export function pkgEditeOperation( data: Ref<any[]>, d, u) {
    if (u.isUpdate) {
      //更新
      var _data = data.value.map((item) => {
        if (item['ID'] == d.ID)
          return {
            ...item,
            PKG_CODE: d.PKG_CODE,
            PKG_LEVEL: d.PKG_LEVEL,
            PKG_QTY: d.PKG_QTY,
            LABEL_CODE: d.LABEL_CODE,
            REMARK: d.REMARK,
          };
        return item;
      });
      data.value = _data;
    } else {
      //新增
      d.ID = buildUUID();
      d.CREATE_USER = useUserStore().getUserInfo.userId as string;
      d.UPDATE_TIME = formatToDateTime(new Date());
      d.UPDATE_USER = useUserStore().getUserInfo.userId as string;
      var _data2: any[] = [];
      if (!isNullOrEmpty(data.value)) {
        _data2 = data.value.map((item) => {
          return item;
        });
      }
      _data2.push(d);
      data.value = _data2;
    }
  }

/**
 * @description: 包装规则主基本信息表单字段
 * @return {*}
 */
export const pkgBaseSchema: FormSchema[] = [
    {
      field: 'RULE_CODE',
      label: '包装规则编码',
      component: 'Input',
      required: true,
      colProps: {
        span: 8,
      },
    },
    {
      label: '包装规则名称',
      field: 'RULE_NAME',
      required: true,
      component: 'Input',
      colProps: {
        span: 8,
      },
    },
    {
      label: '是否启用',
      field: 'IS_ACTIVE',
      required: true,
      component: 'Select',
      colProps: {
        span: 8,
      },
      componentProps: {
        options: [
          {
            label: '启用',
            value: 'Y',
            key: 'Y',
          },
          {
            label: '禁用',
            value: 'N',
            key: 'N',
          },
        ],
      },
    },
    {
      label: '备注',
      field: 'REMARK',
      component: 'Input',
      colProps: {
        span: 8,
      },
    },
    {
      label: 'ID',
      field: 'ID',
      component: 'Input',
      colProps: {
        span: 8,
      },
      show: false,
    },
  ];

  /**
 * @description: 包装规则明细查询字段
 * @return {*}
 */
export const pkgSearchSchema: FormSchema[] = [
    {
      field: 'PKG_CODE',
      label: '包装规则编码',
      component: 'Input',
      colProps: {
        span: 8,
      },
    },
  ];

/**
 * @description: 包装规则增删改字段
 * @return {*}
 */
export const pkgCrudSchema: FormSchema[] = [
    {
      field: 'PKG_CODE',
      label: '包装/载具编码',
      component: 'ApiSelect',
      required: true,
      colProps: {
        span: 24,
      },
      componentProps: {
        api: getEntity,
        params: { entityName: 'BAS_PKG_TYPE', sqlcmd: ' 1=1 ' },
        resultField: 'Data.Items',
        labelField: 'PKG_NAME',
        valueField: 'PKG_CODE',
      },
    },
    {
      label: '包装层级',
      field: 'PKG_LEVEL',
      component: 'Input',
      required: true,
      colProps: {
        span: 24,
      },
    },
    {
      label: '包装规则ID',
      field: 'PKG_RULE_ID',
      component: 'Input',
      colProps: {
        span: 24,
      },
      dynamicDisabled: ({ values }) => {
        return true;
      },
    },
    {
      label: '包装数量',
      field: 'PKG_QTY',
      component: 'Input',
      colProps: {
        span: 24,
      },
    },
    {
      label: '备注',
      field: 'REMARK',
      component: 'Input',
      colProps: {
        span: 24,
      },
    },
    {
      label: 'ID',
      field: 'ID',
      component: 'Input',
      colProps: {
        span: 24,
      },
      show: false,
    },
  ];

  /**
   * @description: 包装规则明细表格列
   * @return {*}
   */
  export const pkgBaseColumn: BasicColumn[] = [
    {
      title: '包装/载具编码',
      dataIndex: 'PKG_CODE',
      // ifShow: false,
      width: 180,
    },
    {
      title: '包装层级',
      dataIndex: 'PKG_LEVEL',
    },
    {
      title: '包装数量',
      dataIndex: 'PKG_QTY',
    },
    {
      title: '包装规则ID',
      dataIndex: 'PKG_RULE_ID',
      ifShow: false,
    },
    {
      title: '备注',
      dataIndex: 'REMARK',
    },
    {
      title: '更新时间',
      dataIndex: 'UPDATE_TIME',
    },
    {
      title: '更新人',
      dataIndex: 'UPDATE_USER',
    },
  ];


